==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/RemoveAllActionGroupsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Indicates if all action groups should be removed.
 * @property actionType Action that should be applied.
 * Expected value is 'RemoveAllActionGroups'.
 */
public data class RemoveAllActionGroupsArgs(
    public val actionType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs.builder()
            .actionType(actionType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RemoveAllActionGroupsArgs].
 */
@PulumiTagMarker
public class RemoveAllActionGroupsArgsBuilder internal constructor() {
    private var actionType: Output<String>? = null

    /**
     * @param value Action that should be applied.
     * Expected value is 'RemoveAllActionGroups'.
     */
    @JvmName("smgoryvslluencty")
    public suspend fun actionType(`value`: Output<String>) {
        this.actionType = value
    }

    /**
     * @param value Action that should be applied.
     * Expected value is 'RemoveAllActionGroups'.
     */
    @JvmName("daqpsaijfvdvmihl")
    public suspend fun actionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionType = mapped
    }

    internal fun build(): RemoveAllActionGroupsArgs = RemoveAllActionGroupsArgs(
        actionType = actionType ?: throw PulumiNullFieldException("actionType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/RemoveAllActionGroupsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Indicates if all action groups should be removed.
 * @property actionType Action that should be applied.
 * Expected value is 'RemoveAllActionGroups'.
 */
public data class RemoveAllActionGroupsArgs(
    public val actionType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.RemoveAllActionGroupsArgs.builder()
            .actionType(actionType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RemoveAllActionGroupsArgs].
 */
@PulumiTagMarker
public class RemoveAllActionGroupsArgsBuilder internal constructor() {
    private var actionType: Output<String>? = null

    /**
     * @param value Action that should be applied.
     * Expected value is 'RemoveAllActionGroups'.
     */
    @JvmName("ibwwmilunecxhxdj")
    public suspend fun actionType(`value`: Output<String>) {
        this.actionType = value
    }

    /**
     * @param value Action that should be applied.
     * Expected value is 'RemoveAllActionGroups'.
     */
    @JvmName("feqmiqdemttjdxxx")
    public suspend fun actionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionType = mapped
    }

    internal fun build(): RemoveAllActionGroupsArgs = RemoveAllActionGroupsArgs(
        actionType = actionType ?: throw PulumiNullFieldException("actionType"),
    )
}
